@@ -30,10 +30,10 @@ While it's possible to use the methods below to set a configuration option direc
 
 package Rex::Config;
 
-use v5.12.5;
+use v5.14.4;
 use warnings;
 
-our $VERSION = '1.14.3'; # VERSION
+our $VERSION = '1.16.1'; # VERSION
 
 use Rex::Helper::File::Spec;
 use Rex::Logger;
@@ -73,7 +73,8 @@ our (
   $use_template_ng,             $use_rex_kvm_agent,
   $autodie,                     $task_chaining_cmdline_args,
   $waitpid_blocking_sleep_time, $write_utf8_files,
-  $default_auth,
+  $default_auth,                $augeas_commands_prepend,
+  $local_augeas_backend,
 );
 
 # some defaults
@@ -730,6 +731,7 @@ The value should be set as an array reference, and will be dereferenced as such
 Default is
 
  qw(
+   /usr/gnu/bin
    /bin
    /sbin
    /usr/bin
@@ -749,10 +751,16 @@ sub set_path {
 
 sub get_path {
   if ( !$path ) {
-    return (
-      "/bin",         "/sbin",          "/usr/bin",
-      "/usr/sbin",    "/usr/local/bin", "/usr/local/sbin",
-      "/usr/pkg/bin", "/usr/pkg/sbin"
+    return qw(
+      /usr/gnu/bin
+      /bin
+      /sbin
+      /usr/bin
+      /usr/sbin
+      /usr/local/bin
+      /usr/local/sbin
+      /usr/pkg/bin
+      /usr/pkg/sbin
     );
   }
   return @{$path};
@@ -1632,6 +1640,50 @@ sub get_default_auth {
   return $default_auth // 1;
 }
 
+=head2 set_augeas_commands_prepend
+
+=head2 get_augeas_commands_prepend
+
+Sets and gets the value of the C<$augeas_commands_prepend> configuration variable.
+
+This controls the list of commands Rex should prepend at the beginning of the command file for Augeas operations.
+
+Default is C<[]>.
+
+=cut
+
+sub set_augeas_commands_prepend {
+  my $self = shift;
+  $augeas_commands_prepend = shift;
+  return $augeas_commands_prepend;
+}
+
+sub get_augeas_commands_prepend {
+  return $augeas_commands_prepend // [];
+}
+
+=head2 set_local_augeas_backend
+
+=head2 get_local_augeas_backend
+
+Sets and gets the value of the C<$local_augeas_backend> configuration variable.
+
+This controls which Augeas backend to use for local operations, C<augtool> or C<Config::Augeas>.
+
+Default is C<Config::Augeas>.
+
+=cut
+
+sub set_local_augeas_backend {
+  my $self = shift;
+  $local_augeas_backend = shift;
+  return $local_augeas_backend;
+}
+
+sub get_local_augeas_backend {
+  return $local_augeas_backend // 'Config::Augeas';
+}
+
 =head2 register_set_handler($handler_name, $code)
 
 Register a handler that gets called by I<set>.
