@@ -1,15 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Inventory;
 
-use strict;
+use v5.14.4;
 use warnings;
 
-our $VERSION = '1.12.0'; # VERSION
+our $VERSION = '1.16.1'; # VERSION
 
 use Rex::Inventory::DMIDecode;
 use Rex::Inventory::Hal;
@@ -133,7 +131,7 @@ sub get {
             type          => $hp_raid->{$key}->{"description"},
             model         => $hp_raid->{$key}->{"model"},
             serial_number => $hp_raid->{$key}->{"serial_number"},
-            cache_status =>
+            cache_status  =>
               ( $hp_raid->{$key}->{"cache_status"} eq "OK" ? 1 : 0 ),
             shelfs => \%raid_shelfs,
           }
@@ -209,7 +207,7 @@ sub get {
       host => {
         name   => [ run "hostname -s" ]->[0],
         domain => [ run "hostname -d" || qw() ]->[0],
-        kernel => [ run "uname -r" || qw() ]->[0],
+        kernel => [ run "uname -r"    || qw() ]->[0],
       },
     },
     fusion_inventory => $fusion_inventory_xmlref,
